pub struct StubBehavior {
pub starting_calls: u32,
pub responses: HashMap<String, StubResponses>,
pub throw_on: Option<(Option<String>, Option<String>, String)>,
pub hang_on: Option<String>,
}Fields
starting_calls: u32Force ensureServer to return a “starting” handle for the first N calls for this language; ready on the (N+1)th.
responses: HashMap<String, StubResponses>Force responses by language.
throw_on: Option<(Option<String>, Option<String>, String)>Force any next call for the given op to throw.
hang_on: Option<String>Force the op to hang until the cancel signal fires.